interface Message {
    /**
     * Message ID.
     * @readonly
     */
    _id?: string | null;
    /** Structured message content. */
    content?: MessageContent;
    /**
     * ID of the message sender.
     *
     * Defaults to the caller's ID using the property that matches their identity type.
     *
     * You can override the default behavior when calling
     * `sendMessage()` by using the `sendAs` field from the `options` object.
     *
     * @readonly
     */
    sender?: IdentificationData;
    /**
     * Optional icon and short text providing additional details about the message,
     * such as the app from which the message was sent, or whether the message was an automated response.
     *
     * Currently only 1 badge is supported.
     * @maxSize 1
     */
    badges?: Badge[];
    /**
     * Communication channel to send the message to.
     *
     * Currently messages can be sent to 1 channel only.
     */
    targetChannels?: ChannelTypeWithLiterals[];
    /** Communication channel the message is sent from. */
    sourceChannel?: ChannelTypeWithLiterals;
    /**
     * Reserved for internal use.
     *
     * ID of the application that sent the message.Omitted if the message was sent with the Chat widget.
     * @format GUID
     * @readonly
     */
    appId?: string | null;
    /**
     * __Required.__
     * Controls who can see the message.
     *
     * - `"BUSINESS_AND_PARTICIPANT"`: Visible to the participant and site collaborators.
     * - `"BUSINESS"`: Visible to site collaborators only.
     */
    visibility?: MessageVisibilityWithLiterals;
    /**
     * Sequential ordering of the message.
     *
     * Ensures more accurate sorting than `createdDate`
     * if two messages are sent at the same time.
     * @readonly
     */
    sequence?: string | null;
    /**
     * __Required.__
     * Message direction.
     *
     * - `"BUSINESS_TO_PARTICIPANT"`: The message was sent from the business to the participant.
     * - `"PARTICIPANT_TO_BUSINESS"`: The message was sent from the participant to the business.
     */
    direction?: MessageDirectionWithLiterals;
    /** Date and time the message was sent. */
    _createdDate?: Date | null;
    /**
     * Controls whether the unread count and conversation summary
     * are updated in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     *
     * If `true`, unread count and conversation summary are not updated.
     *
     * Default: `false`
     */
    silent?: boolean;
}
interface MessageContent extends MessageContentPayloadOneOf {
    /** Plain text, file, or image message. */
    basic?: BasicMessagePayload;
    /**
     * Template containing an image, title, text,
     * and/or up to 10 call-to-action buttons.
     */
    template?: TemplateMessagePayload;
    /**
     * Minimal message containing a single line of text
     * and an optional icon.
     * Often reports an activity that took place.
     */
    minimal?: MinimalMessagePayload;
    /**
     * Message containing submitted form data.
     * Typically sent with a `direction` of `"PARTICIPANT_TO_BUSINESS"`
     * and message `visibility` of `"BUSINESS"`.
     */
    form?: FormMessagePayload;
    /**
     * Reserved for internal use.
     *
     * System message.
     */
    system?: SystemMessagePayload;
    /**
     * Summary of message contents.
     * Displayed in Inbox in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     * @maxLength 256
     */
    previewText?: string | null;
    /** Message title. */
    title?: string | null;
}
/** @oneof */
interface MessageContentPayloadOneOf {
    /** Plain text, file, or image message. */
    basic?: BasicMessagePayload;
    /**
     * Template containing an image, title, text,
     * and/or up to 10 call-to-action buttons.
     */
    template?: TemplateMessagePayload;
    /**
     * Minimal message containing a single line of text
     * and an optional icon.
     * Often reports an activity that took place.
     */
    minimal?: MinimalMessagePayload;
    /**
     * Message containing submitted form data.
     * Typically sent with a `direction` of `PARTICIPANT_TO_BUSINESS`
     * and message `visibility` of `BUSINESS`.
     */
    form?: FormMessagePayload;
    /**
     * System message.
     * For internal use.
     */
    system?: SystemMessagePayload;
}
interface BasicMessagePayload {
    /**
     * List of plain text messages, images, and/or files.
     * List items are displayed as separate messages
     * in Inbox and the site's chat widget.
     * @minSize 1
     */
    items?: BasicMessageData[];
}
interface BasicMessageData extends BasicMessageDataDataOneOf {
    /**
     * Text message.
     * @minLength 1
     * @maxLength 16384
     */
    text?: string;
    /**
     * Image message.
     * Can contain an image from Wix Media
     * or from an external provider.
     */
    image?: ImageMessage;
    /**
     * File attachment.
     * Can contain a file from Wix Media or an external provider.
     */
    file?: FileMessage;
}
/** @oneof */
interface BasicMessageDataDataOneOf {
    /**
     * Text message.
     * @minLength 1
     * @maxLength 16384
     */
    text?: string;
    /**
     * Image message.
     * Can contain an image from Wix Media
     * or from an external provider.
     */
    image?: ImageMessage;
    /**
     * File attachment.
     * Can contain a file from Wix Media or an external provider.
     */
    file?: FileMessage;
}
interface ImageMessage {
    /**
     * Wix Media ID.
     * @maxLength 2000
     */
    _id?: string | null;
    /**
     * URL where the image is hosted.
     * @format WEB_URL
     * @maxLength 2000
     */
    url?: string;
    /**
     * File name of the original file.
     * @maxLength 255
     */
    filename?: string | null;
    /** Original image width, in pixels. */
    width?: number;
    /** Original image height, in pixels. */
    height?: number;
}
interface FileMessage {
    /**
     * Wix Media ID.
     * @maxLength 2000
     */
    _id?: string | null;
    /**
     * URL where the file is hosted.
     * @format WEB_URL
     * @maxLength 2000
     */
    url?: string;
    /**
     * File name of the original file.
     * @maxLength 255
     */
    filename?: string | null;
    /**
     * File [MIME type](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types).
     * @maxLength 100
     */
    mimeType?: string | null;
}
interface TemplateMessagePayload {
    /** Title displayed in the message. */
    title?: string | null;
    /**
     * List of buttons to display with the message.
     * Buttons can either open a URL or pass interaction details to the
     * `onMessageButtonInteracted()` event.
     *
     * Max: 10 buttons.
     * @maxSize 10
     */
    buttons?: Button[];
    /** Controls whether the message is displayed in portrait or landscape layout. */
    orientation?: OrientationWithLiterals;
    /**
     * List of lines of text. Each item in the array is displayed on a new line.
     *
     * Max: 10 lines (up to 512 characters per line).
     * @maxSize 10
     */
    textLines?: string[];
    /**
     * URL where the icon is hosted.
     * @format WEB_URL
     * @maxLength 2000
     */
    imageUrl?: string | null;
}
interface Button {
    /**
     * Button label text.
     * @minLength 1
     * @maxLength 16384
     */
    label?: string;
    /**
     * If included, the button launches the specified URL.
     * @format WEB_URL
     * @maxLength 16384
     */
    launchUrl?: string | null;
    /** Properties to pass to the `onMessageButtonInteracted()` event when the button is clicked. */
    postbackProperties?: PostbackProperties;
}
interface PostbackProperties {
    /**
     * For internal use.
     *
     * @readonly
     * @format GUID
     */
    appId?: string | null;
    /**
     * ID you define for the interaction, to be handled by your server.
     * @minLength 1
     * @maxLength 256
     */
    interactionId?: string;
}
declare enum Orientation {
    /** Unknown orientation. */
    UNKNOWN_ORIENTATION = "UNKNOWN_ORIENTATION",
    /** Portrait layout. */
    PORTRAIT = "PORTRAIT",
    /** Landscape layout. */
    LANDSCAPE = "LANDSCAPE"
}
/** @enumType */
type OrientationWithLiterals = Orientation | 'UNKNOWN_ORIENTATION' | 'PORTRAIT' | 'LANDSCAPE';
interface MinimalMessagePayload {
    /**
     * Message text.
     * @minLength 1
     * @maxLength 16384
     */
    text?: string;
    /**
     * URL where the icon is hosted.
     * @format WEB_URL
     * @maxLength 2000
     */
    iconUrl?: string | null;
    /**
     * If included, URL the user is redirected to when clicking the message.
     * @format WEB_URL
     * @maxLength 2000
     */
    url?: string | null;
}
interface FormMessagePayload {
    /**
     * Form title displayed in the message.
     * @minLength 1
     * @maxLength 256
     */
    title?: string | null;
    /**
     * Form description displayed below the title.
     * @minLength 1
     * @maxLength 16384
     */
    description?: string | null;
    /**
     * List of form fields and values.
     * @minSize 1
     * @maxSize 15
     */
    fields?: FormField[];
    /**
     * List of files and/or images attached to the form.
     *
     * List items are displayed as separate messages
     * in Inbox and the site's chat widget.
     * @maxSize 15
     */
    media?: MediaItem[];
}
interface FormField {
    /**
     * Form field display name.
     * @maxLength 8192
     */
    name?: string;
    /**
     * Submitted value.
     * @maxLength 8192
     */
    value?: string;
}
interface MediaItem extends MediaItemMediaOneOf {
    /**
     * Image message.
     * Can contain an image from Wix Media
     * or from an external provider.
     */
    image?: ImageMessage;
    /**
     * File attachment.
     * Can contain a file from Wix Media or an external provider.
     */
    file?: FileMessage;
}
/** @oneof */
interface MediaItemMediaOneOf {
    /**
     * Image message.
     * Can contain an image from Wix Media
     * or from an external provider.
     */
    image?: ImageMessage;
    /**
     * File attachment.
     * Can contain a file from Wix Media or an external provider.
     */
    file?: FileMessage;
}
interface SystemMessagePayload {
    /**
     * Text message. `\n` renders as a line break.
     * @maxLength 16384
     */
    text?: string;
    /**
     * List of buttons to display with the message.
     * Buttons can either open a URL or pass interaction details to the
     * `onMessageButtonInteracted()` event.
     *
     * Maximum: 10 buttons.
     * @maxSize 10
     */
    buttons?: Button[];
    /**
     * URL where the icon is hosted.
     * @format WEB_URL
     * @maxLength 2000
     */
    imageUrl?: string | null;
}
declare enum ContentType {
    UNKNOWN_CONTENT = "UNKNOWN_CONTENT",
    BASIC = "BASIC",
    TEMPLATE = "TEMPLATE",
    MINIMAL = "MINIMAL",
    FORM = "FORM",
    SYSTEM = "SYSTEM",
    UNSUPPORTED = "UNSUPPORTED"
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * Anonymous site visitor ID.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members)
     * ID.
     * @format GUID
     */
    memberId?: string;
    /**
     * User ID of the site owner or a site contributor.
     * @format GUID
     */
    wixUserId?: string;
    /**
     * App ID.
     * @format GUID
     */
    appId?: string;
    /**
     * Optional site
     * [contact](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fcontacts) ID.
     * @format GUID
     * @readonly
     */
    contactId?: string | null;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * Anonymous site visitor ID.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * Site
     * [member](https://www.wix.com/my-account/site-selector/?buttonText=Select%20Site&title=Select%20a%20Site&autoSelectOnSingleSite=true&actionUrl=https:%2F%2Fwww.wix.com%2Fdashboard%2F%7B%7BmetaSiteId%7D%7D%2Fmember-permissions/members)
     * ID.
     * @format GUID
     */
    memberId?: string;
    /**
     * User ID of the site owner or a site contributor.
     * @format GUID
     */
    wixUserId?: string;
    /**
     * App ID.
     * @format GUID
     */
    appId?: string;
}
interface Badge {
    /** Display text. */
    text?: string;
    /**
     * URL where the icon is hosted.
     * @format WEB_URL
     */
    iconUrl?: string | null;
    /**
     * Controls whether the badge is visible to the participant.
     * Currently not supported in the Chat widget.
     */
    badgeVisibility?: BadgeVisibilityWithLiterals;
}
declare enum BadgeVisibility {
    /** Unkown visibility. */
    UNKNOWN_BADGE_VISIBILITY = "UNKNOWN_BADGE_VISIBILITY",
    /** Visible to the participant and site collaborators. */
    BUSINESS_AND_PARTICIPANT = "BUSINESS_AND_PARTICIPANT",
    /** Visible to site collaborators only. */
    BUSINESS = "BUSINESS"
}
/** @enumType */
type BadgeVisibilityWithLiterals = BadgeVisibility | 'UNKNOWN_BADGE_VISIBILITY' | 'BUSINESS_AND_PARTICIPANT' | 'BUSINESS';
declare enum ChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    CHAT = "CHAT",
    EMAIL = "EMAIL",
    SMS = "SMS",
    FACEBOOK = "FACEBOOK",
    INSTAGRAM = "INSTAGRAM",
    WHATSAPP = "WHATSAPP"
}
/** @enumType */
type ChannelTypeWithLiterals = ChannelType | 'UNKNOWN_CHANNEL_TYPE' | 'CHAT' | 'EMAIL' | 'SMS' | 'FACEBOOK' | 'INSTAGRAM' | 'WHATSAPP';
declare enum MessageVisibility {
    /** Unknown message visibility. */
    UNKNOWN_VISIBILITY = "UNKNOWN_VISIBILITY",
    /** Visible to the participant and site collaborators. */
    BUSINESS_AND_PARTICIPANT = "BUSINESS_AND_PARTICIPANT",
    /** Visible to site collaborators only. */
    BUSINESS = "BUSINESS"
}
/** @enumType */
type MessageVisibilityWithLiterals = MessageVisibility | 'UNKNOWN_VISIBILITY' | 'BUSINESS_AND_PARTICIPANT' | 'BUSINESS';
declare enum MessageDirection {
    /** Unknown message direction. */
    UNKNOWN_DIRECTION = "UNKNOWN_DIRECTION",
    /** The message was sent from the business to the participant. */
    BUSINESS_TO_PARTICIPANT = "BUSINESS_TO_PARTICIPANT",
    /** The message was sent from the participant to the business. */
    PARTICIPANT_TO_BUSINESS = "PARTICIPANT_TO_BUSINESS"
}
/** @enumType */
type MessageDirectionWithLiterals = MessageDirection | 'UNKNOWN_DIRECTION' | 'BUSINESS_TO_PARTICIPANT' | 'PARTICIPANT_TO_BUSINESS';
interface GetMessageIndicationsRequest {
    /** @format GUID */
    conversationId?: string;
    messageId?: string;
}
interface GetMessageIndicationsResponse {
    messageIndications?: MessageIndication[];
}
interface MessageIndication {
    /**
     * @readonly
     * @format GUID
     */
    conversationId?: string | null;
    /**
     * The time when the message was sent
     * @readonly
     */
    messageId?: string | null;
    /**
     * The type of the indication
     * - `UNKNOWN_INDICATION_TYPE`: Unknown indication type.
     * - `SENT`: Message was sent.
     * - `SEEN`: Message was seen.
     * - `ERROR`: There was an error.
     * - `DELIVERED`: Message was delivered.
     */
    type?: IndicationTypeWithLiterals;
    /** The channel to which this indication was added */
    channel?: ChannelTypeWithLiterals;
    /** The time when action happened */
    timestamp?: Date | null;
}
declare enum IndicationType {
    /** Unknown indication type. */
    UNKNOWN_INDICATION_TYPE = "UNKNOWN_INDICATION_TYPE",
    /** Message was sent. */
    SENT = "SENT",
    /** Message was seen. */
    SEEN = "SEEN",
    /** There was an error. */
    ERROR = "ERROR",
    /** Message was delivered. */
    DELIVERED = "DELIVERED"
}
/** @enumType */
type IndicationTypeWithLiterals = IndicationType | 'UNKNOWN_INDICATION_TYPE' | 'SENT' | 'SEEN' | 'ERROR' | 'DELIVERED';
interface AddMessageIndicationsRequest {
    /** @format GUID */
    conversationId?: string;
    /** @minSize 1 */
    messageIds?: string[];
    /** by whom this action was done, defaults to PARTICIPANT in case of UNKNOWN_PERFORMED_BY */
    performedBy?: PerformedByWithLiterals;
    indication?: MessageIndication;
}
declare enum PerformedBy {
    /** Unknown performer. */
    UNKNOWN_PERFORMED_BY = "UNKNOWN_PERFORMED_BY",
    /** Business performed the action. */
    BUSINESS = "BUSINESS",
    /** Participant performed the action. */
    PARTICIPANT = "PARTICIPANT"
}
/** @enumType */
type PerformedByWithLiterals = PerformedBy | 'UNKNOWN_PERFORMED_BY' | 'BUSINESS' | 'PARTICIPANT';
interface AddMessageIndicationsResponse {
}
interface MessageSentToParticipant {
    /**
     * Conversation ID.
     * @format GUID
     */
    conversationId?: string;
    /** Sent message. */
    message?: Message;
}
interface CustomMessageData {
    /** Name of the app this message belong to */
    appName?: string | null;
    /** Data set by the sending application */
    appData?: Record<string, string>;
}
interface MessageSentToBusiness {
    /**
     * Conversation ID.
     * @format GUID
     */
    conversationId?: string;
    /** Sent message. */
    message?: Message;
    /** Optional info about interaction with app done by the user */
    interactionInfo?: InteractionInfo;
}
/**
 * Source of interaction message, will be available when message originated by interaction with an application.
 * like clicking a button.
 */
interface InteractionInfo {
    /** @format GUID */
    appId?: string | null;
    interactionId?: string | null;
}
interface ButtonInteracted {
    /**
     * Conversation ID.
     * @format GUID
     */
    conversationId?: string;
    /**
     * [Your app's](https://dev.wix.com/dc3/my-apps) app ID.
     * @format GUID
     */
    appId?: string | null;
    /**
     * ID you define for the interaction,
     * to be handled by your server.
     */
    interactionId?: string | null;
    /** ID of the participant who pressed the button. */
    interactedBy?: IdentificationData;
}
interface ListMessagesRequest {
    /**
     * ID of the conversation that contains the intended messages.
     * @format GUID
     */
    conversationId: string;
    /**
     * __Required.__
     * Filters for messages with the specified visibility setting.
     *
     * - `"BUSINESS_AND_PARTICIPANT"`: Return messages visible to the business and the participant.
     * - `"BUSINESS"`: Return all messages.
     */
    visibility?: MessageVisibilityWithLiterals;
    /** Paging options. */
    paging?: CursorPaging;
    /** Sorting options. */
    sorting?: Sorting;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 100
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface ListMessagesResponse {
    /** List of messages between the specified visitor and the site. */
    messages?: Message[];
    /** Details on the paged set of results returned. */
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface SendMessageRequest {
    /**
     * ID of the conversation to add the message to.
     * @format GUID
     */
    conversationId: string;
    /** Message to send. */
    message: Message;
    /**
     * Controls whether the message triggers notifications when it's received.
     *
     * Default: `false`
     */
    sendNotifications?: boolean;
    /**
     * Controls whether the unread count and conversation summary
     * are updated in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     *
     * If `true`, unread count and conversation summary are not updated.
     * Deprecated: Use `Message.silent` instead.
     *
     * Default: `false`
     * @deprecated Controls whether the unread count and conversation summary
     * are updated in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     *
     * If `true`, unread count and conversation summary are not updated.
     * Deprecated: Use `Message.silent` instead.
     *
     * Default: `false`
     * @replacedBy Message.silent
     * @targetRemovalDate 2026-06-01
     */
    silent?: boolean;
    /**
     * Controls which identity to use in the message's `sender` property.
     * Default: `CALLER`
     * For 3rd-party apps, the app is the caller.
     */
    sendAs?: OverrideSenderOptionsWithLiterals;
}
declare enum OverrideSenderOptions {
    /** Uses the identity included in the request header. */
    CALLER = "CALLER",
    /** Uses the `anonymousVisitorId`, `contactId`, or `memberId` of the conversation's participant. */
    PARTICIPANT = "PARTICIPANT",
    /** For internal use. Uses the `wixUserId` of the person sending messages on behalf of the business. */
    BUSINESS_USER = "BUSINESS_USER"
}
/** @enumType */
type OverrideSenderOptionsWithLiterals = OverrideSenderOptions | 'CALLER' | 'PARTICIPANT' | 'BUSINESS_USER';
interface SendMessageResponse {
    /** Sent message. */
    message?: Message;
}
interface GetMessageRequest {
    /**
     * ID of the conversation the message belongs to
     * @format GUID
     */
    conversationId?: string;
    /**
     * Id of the message to retrieve
     * @maxLength 20
     */
    messageId?: string;
}
interface GetMessageResponse {
    /** The request message */
    message?: Message;
}
interface Empty {
}
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: WebhooksIdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface WebhooksIdentificationData extends WebhooksIdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface WebhooksIdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: WebhooksIdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface MessageButtonInteractedEnvelope {
    data: ButtonInteracted;
    metadata: EventMetadata;
}
interface MessageSentToBusinessEnvelope {
    data: MessageSentToBusiness;
    metadata: EventMetadata;
}
interface ListMessagesOptions {
    /** Paging options. */
    paging?: CursorPaging;
    /** Sorting options. */
    sorting?: Sorting;
}
interface SendMessageOptions {
    /**
     * Controls whether the message triggers notifications when it's received.
     *
     * Default: `false`
     */
    sendNotifications?: boolean;
    /**
     * Controls whether the unread count and conversation summary
     * are updated in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     *
     * If `true`, unread count and conversation summary are not updated.
     * Deprecated: Use `Message.silent` instead.
     *
     * Default: `false`
     * @deprecated Controls whether the unread count and conversation summary
     * are updated in the
     * [Message List](https://support.wix.com/en/article/wix-inbox-getting-started#view-your-messages).
     *
     * If `true`, unread count and conversation summary are not updated.
     * Deprecated: Use `Message.silent` instead.
     *
     * Default: `false`
     * @replacedBy Message.silent
     * @targetRemovalDate 2026-06-01
     */
    silent?: boolean;
    /**
     * Controls which identity to use in the message's `sender` property.
     *
     * - `"CALLER"`: Uses the identity of the initiator of the sent message.
     * - `"PARTICIPANT"`: Uses the `anonymousVisitorId`, `contactId`, or `memberId` of the conversation's participant.
     *
     * Default: `"CALLER"`
     *
     */
    sendAs?: OverrideSenderOptionsWithLiterals;
}

export { type SendMessageRequest as $, type Badge as A, BadgeVisibility as B, ContentType as C, type GetMessageIndicationsResponse as D, type MessageIndication as E, type FileMessage as F, type GetMessageIndicationsRequest as G, type AddMessageIndicationsRequest as H, IndicationType as I, type AddMessageIndicationsResponse as J, type MessageSentToParticipant as K, type ListMessagesOptions as L, type MessageVisibilityWithLiterals as M, type CustomMessageData as N, Orientation as O, PerformedBy as P, type MessageSentToBusiness as Q, type InteractionInfo as R, type SendMessageOptions as S, type TemplateMessagePayload as T, type ButtonInteracted as U, type ListMessagesRequest as V, WebhookIdentityType as W, type CursorPaging as X, type Sorting as Y, type PagingMetadataV2 as Z, type Cursors as _, type ListMessagesResponse as a, type GetMessageRequest as a0, type GetMessageResponse as a1, type Empty as a2, type DomainEvent as a3, type DomainEventBodyOneOf as a4, type EntityCreatedEvent as a5, type RestoreInfo as a6, type EntityUpdatedEvent as a7, type EntityDeletedEvent as a8, type ActionEvent as a9, type MessageEnvelope as aa, type WebhooksIdentificationData as ab, type WebhooksIdentificationDataIdOneOf as ac, type BaseEventMetadata as ad, type EventMetadata as ae, type Message as b, type SendMessageResponse as c, type MessageButtonInteractedEnvelope as d, type MessageSentToBusinessEnvelope as e, ChannelType as f, MessageVisibility as g, MessageDirection as h, SortOrder as i, OverrideSenderOptions as j, type MessageContent as k, type MessageContentPayloadOneOf as l, type BasicMessagePayload as m, type BasicMessageData as n, type BasicMessageDataDataOneOf as o, type ImageMessage as p, type Button as q, type PostbackProperties as r, type MinimalMessagePayload as s, type FormMessagePayload as t, type FormField as u, type MediaItem as v, type MediaItemMediaOneOf as w, type SystemMessagePayload as x, type IdentificationData as y, type IdentificationDataIdOneOf as z };
